-----------------------------------------------------------------------------------------------
-- Client Lua Script for SimpleKineticEnergy
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Apollo"
require "GameLib"
require "Window"
require "Unit"

-------------------------------------------------------------------------------------
-- SimpleKineticEnergy Module Definition
-----------------------------------------------------------------------------------------------
local SimpleKineticEnergy = {} 
local warriorResourceAddon = Apollo.GetAddon("TechWarrior")

-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function SimpleKineticEnergy:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    return o
end

function SimpleKineticEnergy:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {"WarriorResource"}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 
-----------------------------------------------------------------------------------------------
-- SimpleKineticEnergy OnLoad
-----------------------------------------------------------------------------------------------
function SimpleKineticEnergy:OnLoad()
	self:InitializeHooks()
end

function SimpleKineticEnergy:InitializeHooks()
	warriorResourceAddon.OnFrame = self.OnFrame
end

function SimpleKineticEnergy:OnFrame(strName, nCnt)
	-- Hide base frame
	self.wndResourceBar:Show(false)
	self.wndResourceBar:SetSprite("")
	self.wndResourceBar:FindChild("Base"):Show(false)
	self.wndResourceBar:FindChild("Base"):SetSprite("")
	--
	local unitPlayer = GameLib.GetPlayerUnit()
	if unitPlayer == nil then
		return
	elseif unitPlayer:GetClassId() ~= GameLib.CodeEnumClass.Warrior then
		if self.wndResourceBar then
			self.wndResourceBar:Show(false)
			self.wndResourceBar:Destroy()
		end
		return
	end

	if not self.wndResourceBar:IsValid() then
		return
	end

	local nLeft0, nTop0, nRight0, nBottom0 = self.wndResourceBar:GetRect()
	Apollo.SetGlobalAnchor("CastingBarBottom", 0.0, nTop0 - 15, true)

	local bOverdrive = GameLib.IsOverdriveActive()
	local nResourceCurr = unitPlayer:GetResource(1)
	local nResourceMax = unitPlayer:GetMaxResource(1)

	self.wndResourceBar:FindChild("ChargeBar"):SetMax(nResourceMax)
	self.wndResourceBar:FindChild("ChargeBar"):SetProgress(nResourceCurr)

	if bOverdrive and not self.bOverDriveActive then
		self.bOverDriveActive = true
		self.wndResourceBar:FindChild("ChargeBarOverdriven"):SetProgress(100)
		Apollo.CreateTimer("WarriorResource_ChargeBarOverdriveTick", 0.01, false)
		Apollo.CreateTimer("WarriorResource_ChargeBarOverdriveDone", 10, false)
		-- New
		self.wndResourceBar:FindChild("ResourceCount"):SetScale(1.3)
		self.wndResourceBar:FindChild("ResourceCount"):SetTextColor("xkcdBloodOrange")
		self.wndResourceBar:FindChild("ResourceCount"):SetAnchorOffsets(-70, -130, 30, -80)
		self.wndResourceBar:FindChild("Skulls"):SetOpacity(0.5)
		--
	end
	
	local wndBase = self.wndResourceBar:FindChild("Base")
	local wndSkulls = self.wndResourceBar:FindChild("Skulls")
	local wndSplit = self.wndResourceBar:FindChild("InsetFrameDivider")
	self.wndResourceBar:FindChild("ChargeBarOverdriven"):Show(bOverdrive)
	self.wndResourceBar:FindChild("ChargeBar"):Show(not bOverdrive)
	self.wndResourceBar:FindChild("InsetFrameDivider"):Show(not bOverdrive)
	self.wndResourceBar:FindChild("Bar"):SetSprite(bOverdrive and "spr_CM_Warrior_Innate" or "spr_CM_Warrior_Bar")
	
	local strBaseSprite = ""
	local strSkullIndex = ""
	local strSplitSprite = ""
	local strSkullSprite = ""
	
	if bOverdrive then
		self.wndResourceBar:FindChild("Bar"):Show(true)
		self.wndResourceBar:FindChild("ResourceCount"):SetText(Apollo.GetString("WarriorResource_OverdriveCaps"))
		self.wndResourceBar:FindChild("ResourceCount"):SetTextColor(ApolloColor.new("xkcdAmber"))
		
		strBaseSprite = "spr_CM_Warrior_Base_Innate"
		strSkullSprite = "Skull0"
	else
		local bInCombat = unitPlayer:IsInCombat()
		
		self.wndResourceBar:FindChild("InsetFrameDivider"):Show(nResourceCurr > 0 or bInCombat)
		self.wndResourceBar:FindChild("ResourceCount"):SetText(nResourceCurr == 0 and "" or nResourceCurr)
		
		self.wndResourceBar:FindChild("ResourceCount"):SetTextColor(ApolloColor.new("xkcdOrangeish"))		
		self.wndResourceBar:FindChild("Bar"):Show(nResourceCurr > 0 or bInCombat)
		-- New
		if nResourceCurr > 499 then
			self.wndResourceBar:FindChild("ResourceCount"):SetScale(1.1)
			self.wndResourceBar:FindChild("ResourceCount"):SetTextColor("xkcdCoral")
			self.wndResourceBar:FindChild("ResourceCount"):SetAnchorOffsets(-62, -126, 38, -76)
			self.wndResourceBar:FindChild("Skulls"):SetOpacity(0.6)
		end	
		if nResourceCurr > 749 then
			self.wndResourceBar:FindChild("ResourceCount"):SetScale(1.3)
			self.wndResourceBar:FindChild("ResourceCount"):SetTextColor("Red")
			self.wndResourceBar:FindChild("ResourceCount"):SetAnchorOffsets(-70, -130, 30, -80)
			self.wndResourceBar:FindChild("Skulls"):SetOpacity(1)
		end
		if nResourceCurr < 500 then
			self.wndResourceBar:FindChild("ResourceCount"):SetScale(1)
			self.wndResourceBar:FindChild("ResourceCount"):SetTextColor(ApolloColor.new("xkcdOrangeish"))
			self.wndResourceBar:FindChild("ResourceCount"):SetAnchorOffsets(-58, -124, 42, -74)
			self.wndResourceBar:FindChild("Skulls"):SetOpacity(0.3)
		end
		--
		strBaseSprite = bInCombat and "spr_CM_Warrior_Base_InCombat" or "spr_CM_Warrior_Base_OutOfCombatFade"
		strSkullIndex = not bInCombat and "" or nResourceCurr > 750 and "4" or nResourceCurr > 500 and "3" or nResourceCurr > 250 and "2" or nResourceCurr > 0 and "1" or bInCombat and "1" or ""
		strSkullSprite = "Skull"..strSkullIndex
		strSplitSprite = nResourceMax > 1000 and "spr_CM_Warrior_Split4" or "spr_CM_Warrior_Split3"
	end
	
	if wndBase:GetData() ~= strBaseSprite then
		wndBase:SetSprite(strBaseSprite)
		wndBase:SetData(strBaseSprite)
	end
	
	if wndSkulls:GetData() ~= strSkullSprite then
		wndSkulls:SetSprite(strSkullSprite)
		wndSkulls:SetData(strSkullSprite)
		
		self.wndResourceBar:FindChild("Skull"):Show(false, false, 0.05)
		self.wndResourceBar:FindChild("Skull0"):Show(false, false, 0.05)
		self.wndResourceBar:FindChild("Skull1"):Show(false, false, 0.05)
		self.wndResourceBar:FindChild("Skull2"):Show(false, false, 0.05)
		self.wndResourceBar:FindChild("Skull3"):Show(false, false, 0.05)
		self.wndResourceBar:FindChild("Skull4"):Show(false, false, 0.05)
		self.wndResourceBar:FindChild(strSkullSprite):Show(true, false, 0.05)
	end	
	
	if wndSplit:GetData() ~= strSplitSprite then
		wndSplit:SetSprite(strSplitSprite)
		wndSplit:SetData(strSplitSprite)
	end
	
	local unitPlayer = GameLib.GetPlayerUnit()
	local nVisibility = Apollo.GetConsoleVariable("hud.ResourceBarDisplay")
	
	if nVisibility == 2 then --always off
		self.wndResourceBar:Show(false)
	elseif nVisibility == 3 then --on in combat
		self.wndResourceBar:Show(unitPlayer:IsInCombat())	
	elseif nVisibility == 4 then --on out of combat
		self.wndResourceBar:Show(not unitPlayer:IsInCombat())
	else
		self.wndResourceBar:Show(true)
	end
end

-----------------------------------------------------------------------------------------------
-- SimpleKineticEnergy Instance
-----------------------------------------------------------------------------------------------
local SimpleKineticEnergyInst = SimpleKineticEnergy:new()
SimpleKineticEnergyInst:Init()
